Coverage for PIL\__init__.py: 0%

# Coverage for PIL\__init__.py : 0%

## 6 statements 0 run 6 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 | """Pillow {} (Fork of the Python Imaging Library) Pillow is the friendly PIL fork by Alex Clark and Contributors. https://github.com/python-pillow/Pillow/ Pillow is forked from PIL 1.1.7. PIL is the Python Imaging Library by Fredrik Lundh and Contributors. Copyright (c) 1999 by Secret Labs AB. Use PIL.__version__ for this Pillow version. PIL.VERSION is the old PIL version and will be removed in the future. ;-) """ from . import _version # VERSION is deprecated and will be removed in Pillow 6.0.0. # PILLOW_VERSION is deprecated and will be removed after that. # Use __version__ instead. VERSION = '1.1.7' # PIL Version PILLOW_VERSION = __version__ = _version.__version__ del _version __doc__ = __doc__.format(__version__) # include version in docstring _plugins = ['BlpImagePlugin', 'BmpImagePlugin', 'BufrStubImagePlugin', 'CurImagePlugin', 'DcxImagePlugin', 'DdsImagePlugin', 'EpsImagePlugin', 'FitsStubImagePlugin', 'FliImagePlugin', 'FpxImagePlugin', 'FtexImagePlugin', 'GbrImagePlugin', 'GifImagePlugin', 'GribStubImagePlugin', 'Hdf5StubImagePlugin', 'IcnsImagePlugin', 'IcoImagePlugin', 'ImImagePlugin', 'ImtImagePlugin', 'IptcImagePlugin', 'JpegImagePlugin', 'Jpeg2KImagePlugin', 'McIdasImagePlugin', 'MicImagePlugin', 'MpegImagePlugin', 'MpoImagePlugin', 'MspImagePlugin', 'PalmImagePlugin', 'PcdImagePlugin', 'PcxImagePlugin', 'PdfImagePlugin', 'PixarImagePlugin', 'PngImagePlugin', 'PpmImagePlugin', 'PsdImagePlugin', 'SgiImagePlugin', 'SpiderImagePlugin', 'SunImagePlugin', 'TgaImagePlugin', 'TiffImagePlugin', 'WebPImagePlugin', 'WmfImagePlugin', 'XbmImagePlugin', 'XpmImagePlugin', 'XVThumbImagePlugin']